TU Delft
Aerospace Engineering
Aerospace Structures and Computational Mechanics
Stability and Analysis of Structures II
Ae4-ASM-511

This Python module can be used by the students to assist them in the
assignments 


License
-------
Distrubuted in the 2-Clause BSD license (https://raw.github.com/saullocastro/tudaesasII/master/LICENSE).

Contact: S.G.P.Castro@tudelft.nl

